package de.intevation.gnv.raster;

import org.w3c.dom.Element;

/**
 * Interface to model transformations of rasters.
 * @author <a href="mailto:sascha.teichmann@intevation.de">Sascha L. Teichmann</a>
 */
public interface Filter
{
    /**
     *  Allows the creation of filters parameterized from XML elements.
     */
    public interface Factory {

        /**
         * Setup the factory with a given XML element.
         * @param element
         */
        void init(Element element);

        /**
         * Created a new Filter with this factory.
         * @return The new created Filter.
         */
        Filter create();

    } // interface Factory

    /**
     * Apply this filter to a given raster. The original raster is
     * unmodified and a new raster is created.
     * @param raster The original raster.
     * @return The new raster.
     */
    Raster filter(Raster raster);
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
